% QuadrExactLS.m exact line search for quadratic
%-----------------------------------------------------------------------
% [alpha,j,info] = ArmijoLineSearch( x, dx, g, ObjFun, varargin )
%
% INPUT ARGUMENTS:
% x              point from whih we perform the search
% dx             search direction
% g              gradient of objective at x
% ObjFun         is a function to evaluate the objective f(x)
% varargin       is a number of parameters that are passed to ObjFun
%
% OUTPUT ARGUMENTS:
% alpha          is the step size
% j              is the iteration number at the final step
% info           is an indication of exit
%                   0 = optimal
%                   1 = too many backtracks
%                   2 = dx is not a search direction
%
% Author: Sven Leyffer, Argonne National Laboratory, 2016.
%-----------------------------------------------------------------------
function [alpha, j, info] = QuadrExactLS( x, dx, g, ObjFun, varargin )

[f,g,H] = feval(ObjFun, x);

sHs = dx'*H*dx;
if (sHs <= 0) 
   info  = 1;
   alpha = 0;
else
  alpha = -dx'*g / sHs;
  info  = 0;
end % if
j = 0;
