% [f,g,H] = TriDiag(x) : evaluate quadratic tridiaginal function 
% 
% Sven Leyffer, Argonne National Laboratory, 2016
% ------------------------------------------------------
function [f,g,H] = TriDiag(x)

  % ... get the problem size from input
  n = length(x);

  % ... set up data for 1/2 x^T G x + b^T x
  b = ones(n,1);
  e = ones(n,1);
  G = spdiags([-e 4*e -e],-1:1,n,n);

  % ... evaluate the function
  f = x'*G*x/2 + b'*x;

  if nargout > 1
    % ... evaluate the gradient
    g = G*x + b;
  end

  if nargout > 1
    % ... evaluate the Hessian
    H = G;
  end
